import React, { useContext, useEffect, useRef } from 'react';
import { MapViewerContext } from '../MapView';
import { calculateBoundingBox } from '../utils';

/**
 * 热力图
 */
const HeatMap: React.FC<HeatMapProps> = (props) => {
  const { data, option } = props;
  const { mapViewer } = useContext(MapViewerContext);
  const layer = useRef<any>(null);

  useEffect(() => {
    if (!mapViewer) {
      return;
    }

    const heatMap = new CooGL.HeatMap(mapViewer.scene, mapViewer.graphics);
    /** 计算包围盒 */
    const bound = calculateBoundingBox(data);

    const newD = data.map((v) => {
      return {
        x: v[0],
        y: v[1],
        value: v[2],
      };
    });
    heatMap.create2d(newD, { bounds: bound, radius: 100, ...option });

    layer.current = heatMap;

    /** 移除layer */
    return () => {
      heatMap.destroy();
      layer.current = null;
    };
  }, [mapViewer, data]);

  return undefined;
};

export default HeatMap;
