import { uniqueId } from 'lodash';
import React, { useContext, useEffect, useRef } from 'react';
import { MapViewerContext } from '../MapView';

/**
 * 文本标记
 */
const Label: React.FC<LabelProps> = (props) => {
  const {
    position,
    text,
    showBackground = true,
    backgroundColor = 'rgba(0, 0, 0, 0.6)',
    backgroundPadding = { x: 8, y: 8 },
    pixelOffset = { x: 0, y: 0 },
    onClick,
  } = props;
  const { mapViewer, click$ } = useContext(MapViewerContext);
  const layer = useRef<any>(null);

  /** 订阅文本的点击事件 */
  click$.useSubscription((data: any) => {
    const id = layer.current.id;
    if (id.includes(data.id)) {
      onClick?.();
    }
  });
  useEffect(() => {
    if (!mapViewer) {
      return;
    }

    const labelLayer = CooGL.Layer.fromTextGraphic({
      textContent: text,
      id: uniqueId('label'),
      showBackground: showBackground,
      backgroundColor: backgroundColor,
      backgroundPadding: backgroundPadding,
      position: {
        x: position[0],
        y: position[1],
        z: 1,
      },
      pixelOffset: new CooGL.Vector2(pixelOffset.x, pixelOffset.y),
    });

    mapViewer?.addLayer(labelLayer).then((res: any) => {
      layer.current = res;
    });

    /** 移除layer */
    return () => {
      mapViewer.removeLayer(layer.current);
      layer.current = null;
    };
  }, [position, mapViewer]);

  return null;
};

export default Label;
