import { uniqueId } from 'lodash';
import React, { useContext, useEffect, useRef } from 'react';
import { MapViewerContext } from '../MapView';

/**
 * 标记点
 */
const Marker: React.FC<MakerProps> = (props) => {
  const { position, icon, onClick, width, height } = props;
  const { mapViewer, click$ } = useContext(MapViewerContext);
  const layer = useRef<any>(null);

  /** 订阅marker的点击事件 */
  click$.useSubscription((data: any) => {
    const id = layer.current.id;
    if (id.includes(data.id)) {
      onClick?.();
    }
  });
  useEffect(() => {
    if (!mapViewer) {
      return;
    }

    const imageLayer = CooGL.Layer.fromImageGraphic({
      image: icon,
      id: uniqueId('maker'),
      width: width,
      height: height,
      position: {
        x: position[0],
        y: position[1],
        z: 1,
      },
    });

    mapViewer?.addLayer(imageLayer).then((res: any) => {
      layer.current = res;
    });

    /** 移除layer */
    return () => {
      mapViewer.removeLayer(layer.current);
      layer.current = null;
    };
  }, [position, mapViewer, icon]);

  return null;
};

export default Marker;
