import color from 'color';
import React, { useContext, useEffect, useRef } from 'react';
import { MapViewerContext } from '../MapView';

/**
 * 多边形
 */
const Polygon: React.FC<PolygonProps> = (props) => {
  const {
    points,
    fillColor,
    fillOpacity = 0.2,
    strokeColor,
    strokeWidth,
  } = props;
  const { mapViewer } = useContext(MapViewerContext);
  const layer = useRef<any>(null);

  useEffect(() => {
    if (!mapViewer) {
      return;
    }
    const vectors = points?.map((item) => {
      return {
        x: item[0],
        y: item[1],
        z: 0,
      };
    });
    if (!vectors) {
      return;
    }

    const polygonLayer = CooGL.Layer.fromPolygonGraphic({
      material: color(fillColor).alpha(fillOpacity).hexa(),
      positions: vectors,
      outline: true,
      outlineColor: strokeColor,
      outlineWidth: strokeWidth,
      zIndex: 2000,
    });
    mapViewer?.addLayer(polygonLayer).then((res: any) => {
      layer.current = res;
    });

    /** 移除layer */
    return () => {
      mapViewer.removeLayer(layer.current);
      layer.current = null;
    };
  }, [points, mapViewer]);

  return null;
};

export default Polygon;
