import { uniqueId } from 'lodash';
import React, { useContext, useEffect, useRef } from 'react';
import { MapViewerContext } from '../MapView';

/**
 * 线
 */
const Polyline: React.FC<PolylineProps> = (props) => {
  const { points, width, lineColor = '#000', material, onClick } = props;
  const { mapViewer, click$ } = useContext(MapViewerContext);
  const layer = useRef<any>(null);

  /** 订阅marker的点击事件 */
  click$.useSubscription((data: any) => {
    const id = layer.current.id;
    if (id.includes(data.id)) {
      onClick?.();
    }
  });

  useEffect(() => {
    if (!mapViewer) {
      return;
    }
    const vectors = points?.map((item) => {
      return {
        x: item[0],
        y: item[1],
        z: 10,
      };
    });
    if (!vectors) {
      return;
    }
    let curMaterial = lineColor;

    if (material === 'flowLine') {
      curMaterial = CooGL.MaterialLibrary.createFlow({
        color: lineColor,
      });
    }
    if (material === 'flowLineSegment') {
      curMaterial = CooGL.MaterialLibrary.createFlowLineSegment({
        color: lineColor,
        repeat: 10,
      });
    }
    if (material === 'emptyLine') {
      curMaterial = CooGL.MaterialLibrary.createEmpty({
        color: lineColor,
      });
    }

    if (material === 'arrowLine') {
      curMaterial = CooGL.MaterialLibrary.createArrow(lineColor);
    }

    const polylineLayer = CooGL.Layer.fromPolylineGraphic({
      material: curMaterial,
      positions: vectors,
      width: width,
      id: uniqueId('line'),
    });
    mapViewer?.addLayer(polylineLayer).then((res: any) => {
      layer.current = res;
    });

    /** 移除layer */
    return () => {
      mapViewer.removeLayer(layer.current);
      layer.current = null;
    };
  }, [points, mapViewer]);

  return undefined;
};

export default Polyline;
